@@ -163,6 +163,10 @@ static int assign_cpu_sysfs_fds(int threads_in_system)
 		cpu_idx++;
 	}
 
+	/* Mark extra slots for offline threads unset, see parse_sysfs_values */
+	for (; cpu_idx < threads_in_system; cpu_idx++)
+		cpu_sysfs_fds[cpu_idx].spurr = -1;
+
 	return 0;
 error:
 	fprintf(stderr, "Failed to open %s: %s\n",
@@ -492,6 +496,15 @@ void get_cpu_util_purr(struct sysentry *unused_se, char *buf)
 	delta_purr = get_delta_value("purr");
 	delta_idle_purr = get_delta_value("idle_purr");
 
+	/*
+	 * Given that these values are read from different
+	 * sources (purr from lparcfg and idle_purr from sysfs),
+	 * a small variation in the values is possible.
+	 * In such cases, round down delta_idle_purr to delta_purr.
+	 */
+	if (delta_idle_purr > delta_purr)
+		delta_idle_purr = delta_purr;
+
 	physc = (delta_purr - delta_idle_purr) / delta_tb;
 	physc *= 100.00;
 
@@ -507,6 +520,15 @@ void get_cpu_idle_purr(struct sysentry *unused_se, char *buf)
 	delta_purr = get_delta_value("purr");
 	delta_idle_purr = get_delta_value("idle_purr");
 
+	/*
+	 * Given that these values are read from different
+	 * sources (purr from lparcfg and idle_purr from sysfs),
+	 * a small variation in the values is possible.
+	 * In such cases, round down delta_idle_purr to delta_purr.
+	 */
+	if (delta_idle_purr > delta_purr)
+		delta_idle_purr = delta_purr;
+
 	physc = (delta_purr - delta_idle_purr) / delta_tb;
 	idle = (delta_purr / delta_tb) - physc;
 	idle *= 100.00;
@@ -866,13 +888,15 @@ void get_smt_mode(struct sysentry *se, char *buf)
 	}
 
 	smt_state = parse_smt_state();
-	if (smt_state < 0) {
+	if (smt_state == -1) {
 		fprintf(stderr, "Failed to get smt state\n");
 		return;
 	}
 
 	if (smt_state == 1)
 		sprintf(buf, "Off");
+	else if (smt_state == 0)
+		sprintf(buf, "Mixed");
 	else
 		sprintf(buf, "%d", smt_state);
 }
